import {Component, HostListener, Input, OnInit, ViewChild} from '@angular/core';
import {EditorNodeContract} from '../EditorNode.contract';
import {EditorService} from '../../../service/editor.service';

@Component({
    selector: 'editor-norm',
    templateUrl: './norm.component.html',
    styleUrls: ['./norm.component.scss'],
})
export class NormComponent extends EditorNodeContract implements OnInit {
    @ViewChild('editable') editable;
    @Input() nodeId: string;
    @Input() editorUUID?: string;

    public initialValue = 'Click to edit...';
    protected savedValue = 'Click to edit...';
    public contents = '';
    private dirtyOverride = false;

    constructor(
        public editorService: EditorService,
    ) {
        super();
        this.contents = this.initialValue;
        this.savedValue = this.initialValue;
    }

    public isDark() {
        return document.body.classList.contains('dark');
    }

    public isDirty(): boolean | Promise<boolean> {
        return this.dirtyOverride || this.contents !== this.savedValue;
    }

    public get isReadonly(): boolean {
        return !this.editorService.canEdit();
    }

    public writeChangesToNode(): void | Promise<void> {
        this.nodeRec.value = this.contents;
        this.savedValue = this.contents;
    }

    ngOnInit() {
        this.editorService = this.editorService.getEditor(this.editorUUID);
        this.editorService.registerNodeEditor(this.nodeId, this).then(() => {
            if ( !this.node.Value ) {
                this.node.Value = {};
            }

            if ( this.node.Value.Value ) {
                this.initialValue = this.node.Value.Value;
                this.savedValue = this.node.Value.Value;
            }

            this.contents = this.initialValue;
        });
    }

    onContentsChanged(contents: string) {
        if ( this.contents !== contents ) {
            this.contents = contents;
            this.editorService.triggerSave();
        }
    }
}
